@@ -17,13 +17,13 @@
 #ifndef KDEVELOP_CODEGENERATOR_H
 #define KDEVELOP_CODEGENERATOR_H
 
-#include <kjob.h>
-
 #include "language/editor/documentrange.h"
 #include "../duchain/indexedstring.h"
 #include "../duchain/topducontext.h"
 #include "../duchain/duchain.h"
 
+#include "language/interfaces/iastcontainer.h"
+
 namespace KDevelop
 {
 template<class AstNode >
@@ -48,10 +48,8 @@ class DocumentChangeSet;
  * \see CodeGenerator
  * \author Hamish Rodda <rodda@kde.org>
  */
-class KDEVPLATFORMLANGUAGE_EXPORT CodeGeneratorBase : public KJob
+class KDEVPLATFORMLANGUAGE_EXPORT CodeGeneratorBase
 {
-    Q_OBJECT
-
 public:
     CodeGeneratorBase();
     virtual ~CodeGeneratorBase();
@@ -88,14 +86,26 @@ public:
      */
     virtual bool process() = 0;
     
-    /**
-     * Retrieve the text edits to be performed as a result of this code generation.
-     */
-    DocumentChangeSet* textEdits() const;
+    const QString & errorText() const;
     
     // Implementation from kJob
-    virtual void start(void);
+    bool execute();
 
+    /**
+     * @brief Indicates that this generation should not expect interaction with the user/
+     * Most probable scenarios are: Testing, and a generator that is being used by another one
+     * @param context If not NULL, the custom context to use, instead of user selection
+     * @param position If not NULL, the cursom range to use instead of user selection
+     * @note If this function is called, then gather information will not be called. Derived classes should provide 
+     * an alternative way of setting up the generator.
+     */
+    void autoGenerate(DUContext * context, const DocumentRange * range);
+    
+    /**
+     * \return The Document Change set to add a single Change, it is more addicient than creating a local DocumentChangeSet and merging it
+     */
+    DocumentChangeSet & documentChangeSet();
+    
 
 protected:
 
@@ -107,16 +117,27 @@ protected:
      */
     void addChangeSet(DUChainChangeSet* duChainChange);
     
+    void addChangeSet(DocumentChangeSet & docChangeSet);
+    
     /**
      * Accessor for KJob's KJob::setErrorText.
      */
     void setErrorText(const QString & error);
+    
+    /**
+     * Inform the derived class if this generation is being performed without user interaction
+     */
+    bool autoGeneration() const;
+    
+    /**
+     * Clean up all the change sets that this generator is in charge of
+     */
+    void clearChangeSets();
 
 private:
     class CodeGeneratorPrivate * const d;
     
-    void executeGenerator(void);
-    bool displayChanges(void);
+    bool displayChanges();
 };
 
 /**
@@ -133,7 +154,10 @@ template <typename AstContainer>
 class CodeGenerator : public CodeGeneratorBase
 {
 public:
-    CodeGenerator() {}
+    ~CodeGenerator()
+    {
+        clearChangeSets();
+    }
     
 protected:
     
@@ -146,17 +170,32 @@ protected:
      */
     TopAstNode * ast(const IndexedString & file)
     {
-        typename AstContainer::Ptr & container = m_AstContainers[file];
-        if(container.isNull)
+        return astContainer(file)->topAstNode();
+    }
+    
+    TopAstNode * ast(const TopDUContext & context)
+    {
+        return astContainer(context)->topAstNode();
+    }
+    
+    typename AstContainer::Ptr astContainer(const IndexedString & file)
+    {
+        if(!m_AstContainers.contains(file))
         {
             kDebug() << "Ast requested for: " << file.str();
-            TopDUContext * context = DUChain::self()->chainForDocument(file);
+            
+            TopDUContext * context = DUChain::self()->waitForUpdate(file, KDevelop::TopDUContext::AST).data();
             
             Q_ASSERT(context);
-            m_AstContainers[file] = AstContainer::Ptr( context->ast().data() );
+            m_AstContainers[file] = AstContainer::Ptr::template staticCast<IAstContainer>( context->ast() );
         }
         
-        return container->topAstNode();
+        return m_AstContainers[file];
+    }
+    
+    typename AstContainer::Ptr astContainer(const TopDUContext & context)
+    {
+        return astContainer(context.url());
     }
     
     /**
@@ -169,6 +208,11 @@ protected:
         CodeGeneratorBase::addChangeSet(duChainChange);
     }
     
+    void addChangeSet(DocumentChangeSet & doc)
+    {
+        CodeGeneratorBase::addChangeSet(doc);
+    }
+    
     /**
      * Generate text edits from duchain / ast change set.
      *
@@ -176,6 +220,19 @@ protected:
      */
     void addChangeSet(LanguageChangeSet * astChange);
     
+    void clearChangeSets()
+    {
+        CodeGeneratorBase::clearChangeSets();
+    }
+    
+    /**
+     * Inform the derived class if this generation is being performed without user interaction
+     */
+    bool autoGeneration() const
+    {
+        return CodeGeneratorBase::autoGeneration();
+    }
+    
     /**
      * Accessor for KJob's KJob::setErrorText.
      */
