@@ -22,14 +22,9 @@
 
 #include "problemwidget.h"
 
-#include <QHeaderView>
 #include <QMenu>
 #include <QCursor>
 #include <QContextMenuEvent>
-#include <QFrame>
-#include <QHBoxLayout>
-#include <QVBoxLayout>
-#include <QToolButton>
 
 #include <klocale.h>
 #include <kicon.h>
@@ -77,7 +72,7 @@ ProblemWidget::ProblemWidget(QWidget* parent, ProblemReporterPlugin* plugin)
     m_fullUpdateAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     m_fullUpdateAction->setText(i18n("Force Full Update"));
     m_fullUpdateAction->setToolTip(i18n("Re-parse the current file and all its imports."));
-    m_fullUpdateAction->setIcon(KIcon("dirsync"));
+    m_fullUpdateAction->setIcon(KIcon("view-refresh"));
     connect(m_fullUpdateAction, SIGNAL(triggered(bool)), this, SLOT(forceFullUpdate()));
     addAction(m_fullUpdateAction);
     //new ModelTest(model());
@@ -127,7 +122,7 @@ void ProblemWidget::forceFullUpdate() {
         return;
     }
     DUChainReadLocker lock(DUChain::lock());
-    DUChain::self()->updateContextForUrl(IndexedString(m_activeUrl), KDevelop::TopDUContext::ForceUpdateRecursive);
+    DUChain::self()->updateContextForUrl(IndexedString(m_activeUrl), (TopDUContext::Features)(KDevelop::TopDUContext::VisibleDeclarationsAndContexts | KDevelop::TopDUContext::ForceUpdateRecursive));
 }
 
 void ProblemWidget::showProblems(TopDUContext* ctx)
@@ -154,6 +149,8 @@ void ProblemWidget::documentActivated(KDevelop::IDocument* doc)
 
   KDevelop::TopDUContext* chosen = 0;
 
+  DUChainReadLocker lock;
+  
   foreach( KDevelop::ILanguage* language, languages)
     if(!chosen)
       chosen = language->languageSupport()->standardContext(doc->url(), true);
@@ -166,6 +163,8 @@ void ProblemWidget::parseJobFinished(KDevelop::ParseJob* job)
   KUrl url = job->document().toUrl();
   IDocument* active = ICore::self()->documentController()->activeDocument();
 
+  DUChainReadLocker lock;
+  
   if(active) {
     //For now, only show problems from the current document
     if(active->url() == url && job->duChain()) {
