@@ -85,7 +85,8 @@ class KDEVPLATFORMPROJECT_EXPORT ProjectBaseItem: public QStandardItem
             ExecutableTarget = QStandardItem::UserType+2  /** item is an executable target */,
             LibraryTarget = QStandardItem::UserType+3     /** item is a library target */,
             Target = QStandardItem::UserType+5            /** item is a target */,
-            File = QStandardItem::UserType+6              /** item is a file */
+            File = QStandardItem::UserType+6              /** item is a file */,
+            CustomProjectItemType = QStandardItem::UserType+100 /** type which should be used as base for custom types */
         };
         
         /** @returns Returns the project that the item belongs to.  */
@@ -118,6 +119,8 @@ class KDEVPLATFORMPROJECT_EXPORT ProjectBaseItem: public QStandardItem
         /** @returns the url of this item if its a file or folder related object */
         virtual KUrl url() const;
 
+        virtual bool lessThan( const KDevelop::ProjectBaseItem* ) const;
+
     protected:
         class ProjectBaseItemPrivate* const d_ptr;
         ProjectBaseItem( ProjectBaseItemPrivate& dd );
@@ -247,6 +250,7 @@ class KDEVPLATFORMPROJECT_EXPORT ProjectFileItem: public ProjectBaseItem
 {
 public:
     ProjectFileItem( IProject*, const KUrl& file, QStandardItem *parent = 0 );
+    ~ProjectFileItem();
 
     ///Reimplemented from QStandardItem
     virtual int type() const;
@@ -295,6 +299,9 @@ private:
     class ProjectModelPrivate* const d;
 };
 
+KDEVPLATFORMPROJECT_EXPORT QStringList joinProjectBasePath( const QStringList& partialpath, KDevelop::ProjectBaseItem* item );
+KDEVPLATFORMPROJECT_EXPORT QStringList removeProjectBasePath( const QStringList& fullpath, KDevelop::ProjectBaseItem* item );
+
 }
 
 #endif // KDEVPROJECTMODEL_H
