@@ -245,6 +245,14 @@ void MainWindow::saveSettings()
     /* This will try to save window size, too.  But it's OK, since we
        won't use this information when loading.  */
     saveMainWindowSettings(cg);
+
+    //debugToolBar visibility is stored separately to allow a area dependent default value
+    foreach (KToolBar* toolbar, toolBars()) {
+        if (toolbar->objectName() == "debugToolBar") {
+            cg.writeEntry("debugToolBarVisibility", toolbar->isVisible());
+        }
+    }
+
     cg.sync();
 }
 
@@ -285,18 +293,6 @@ void MainWindow::loadSettings()
             KToolBar::setToolBarsLocked(false);
     }
 
-    int n = 1; // Toolbar counter. toolbars are counted from 1,
-    foreach (KToolBar* toolbar, toolBars()) {
-        QString group("Toolbar");
-        // Give a number to the toolbar, but prefer a name if there is one,
-        // because there's no real guarantee on the ordering of toolbars
-        group += (toolbar->objectName().isEmpty() ? QString::number(n) : QString(" ")+toolbar->objectName());
-
-        KConfigGroup toolbarGroup(&cg, group);
-        toolbar->applySettings(toolbarGroup, false);
-        n++;
-    }
-   
     // Utilise the QMainWindow::restoreState() functionality
     // Note that we're fixing KMainWindow bug here -- the original
     // code has this fragment above restoring toolbar properties.
@@ -309,10 +305,28 @@ void MainWindow::loadSettings()
         // One day will need to load the version number, but for now, assume 0
         restoreState(state);
     } else {
-        // If there's no state we use a default size of 700x600
-        resize(700,600);
+        // If there's no state we use a default size of 870x650
+        resize(870,650);
     }
-    
+
+    int n = 1; // Toolbar counter. toolbars are counted from 1,
+    foreach (KToolBar* toolbar, toolBars()) {
+        QString group("Toolbar");
+        // Give a number to the toolbar, but prefer a name if there is one,
+        // because there's no real guarantee on the ordering of toolbars
+        group += (toolbar->objectName().isEmpty() ? QString::number(n) : QString(" ")+toolbar->objectName());
+
+        KConfigGroup toolbarGroup(&cg, group);
+        toolbar->applySettings(toolbarGroup, false);
+
+        if (toolbar->objectName() == "debugToolBar") {
+            //debugToolBar visibility is stored separately to allow a area dependent default value
+            bool visibility = cg.readEntry("debugToolBarVisibility", area()->objectName() == "debug");
+            toolbar->setVisible(visibility);
+        }
+        n++;
+    }
+
     KConfigGroup uiGroup = KGlobal::config()->group("UiSettings");
     foreach (Container *container, findChildren<Container*>())
     {
