@@ -40,7 +40,6 @@ public:
     virtual QWidget* create(ToolDocument *doc, QWidget *parent = 0) = 0;
     virtual QList<QAction*> toolBarActions( QWidget* viewWidget ) const = 0;
     virtual QString id() const = 0;
-    virtual bool viewsWantProgressIndicator() const = 0;
 };
 
 /**
@@ -78,16 +77,11 @@ public:
 protected:
     virtual QWidget *createViewWidget(QWidget *parent = 0);
     ToolFactory *factory() const;
-    
-    /**Creates and returns the new view. Reimplement in subclasses to instantiate
-    views of derived from Sublime::View classes.*/
-    virtual View *newView(Document *doc);
 
 private:
     struct ToolDocumentPrivate * const d;
     
     friend class View;
-    friend class ToolView;
 };
 
 }
